@@ -149,13 +149,13 @@ body<-dashboardBody(
       fluidRow(column(12,bsAlert("yourDataAlert"))),
       fluidRow(
         column(5,
-          fileInput(inputId = "yourFile", label = "Choose file to upload", multiple = FALSE),
-          selectInput('yourFileHeader', 'Headers', choices = c("Auto"="Default","Only columns", "Only rows", "Both", "None"), selected = "Default"),
-          selectInput(inputId = 'yourFileSep', label = 'Field Separator', choices = c("Space"="default", "Comma"=',', "Semicolon"=';', "Tab"='\t'), selected = "default"),
+          fileInput(inputId = "yourFile", width = "60%", label = "Choose file to upload", multiple = FALSE),
+          selectInput('yourFileHeader', 'Headers',width = "60%", choices = c("Auto"="Default","Only columns", "Only rows", "Both", "None"), selected = "Default"),
+          selectInput(inputId = 'yourFileSep',width = "60%", label = 'Field Separator', choices = c("Space"="default", "Comma"=',', "Semicolon"=';', "Tab"='\t'), selected = "default"),
           uiOutput("yourFileIndex"),
           uiOutput("yourFileFUN"),
           br(),
-          div(align = "center", box(background = switch(getOption("yuimaGUItheme"), "black"="black", "white"=NULL),  title = "More Settings", collapsible = TRUE, id = "yourFileMoreSettings", collapsed = TRUE,
+          div(align = "center", style="width:55%", box(background = switch(getOption("yuimaGUItheme"), "black"="black", "white"=NULL), width = 12,  title = "More Settings", collapsible = TRUE, id = "yourFileMoreSettings", collapsed = TRUE,
               textInput('yourFileDec', 'Decimal Separator', value = "."),
               textInput('yourFileThnd', 'Thousands Separator', value = ""),
               textInput("yourFileNA", "Missing Value string", value = "NA"),
